@@ -95,7 +95,7 @@ unsafe fn mdup2(oldfd: RawFd, newfd: RawFd, what: &str) {
 }
 
 unsafe fn write_status(st_wfd: RawFd, estatus: u8) {
-  match write(st_wfd, slice::from_ref(&estatus)) {
+  match compat::write(st_wfd, slice::from_ref(&estatus)) {
     Ok(1) => {}
     Ok(_) => crashm("write child startup exit status: short write"),
     Err(e) => crashe("write child startup exit status", e),
@@ -120,7 +120,7 @@ unsafe fn intermediate(child: Pid, st_wfd: RawFd) -> ! {
 
   let r = libc::waitpid(child.as_raw(), &mut wstatus, 0);
   if r == -1 { crashe("await child startup status",
-                      nix::errno::from_i32(errno())) }
+                      compat::nix_last_errno()) }
   if r != child.as_raw() { crashm("await child startup status: wrong pid") }
 
   let cooked = WaitStatus::from_raw(child, wstatus)
@@ -154,7 +154,7 @@ impl Daemoniser {
         .context("open /dev/null");
       mdup2(null_fd, 0, "null onto stdin");
 
-      let (st_rfd, st_wfd) = pipe().context("pipe");
+      let (st_rfd, st_wfd) = compat::pipe().context("pipe");
 
       match fork().context("fork (1)") {
         ForkResult::Child => { }
