@@ -179,7 +179,7 @@ async fn async_main(opts: Opts, daemon: Option<Daemoniser>) {
       return Ok(None);
     }
 
-    let global_config = config::InstanceConfigGlobal::from(&ics);
+    let global_config = config::InstanceConfigGlobal::from(ics);
     let gc = (&server_name, &global_config);
 
     if pc.keys().all(|k| gc.inspect_key(k).is_some()) {
