@@ -4,44 +4,45 @@
 
 use crate::prelude::*;
 
-#[derive(hippotat_macros::ResolveConfig)]
 #[derive(Debug,Clone)]
+#[derive(Deftly)]
+#[derive_deftly(InspectableConfigAuto, InstanceConfig)]
 pub struct InstanceConfig {
   // Exceptional settings
-  #[special(special_link, SKL::None)]      pub    link:   LinkName,
-  #[per_client]                            pub    secret: Secret,
-  #[global] #[special(special_ipif, SKL::PerClient)] pub ipif: String,
+  #[deftly(special, skl="SKL::None")]              pub link:   LinkName,
+  #[deftly(per_client)]                            pub secret: Secret,
+  #[deftly(global, special, skl="SKL::PerClient")] pub ipif:   String,
 
   // Capped settings:
-  #[limited] pub max_batch_down:               u32,
-  #[limited] pub max_queue_time:               Duration,
-  #[limited] pub http_timeout:                 Duration,
-  #[limited] pub target_requests_outstanding:  u32,
-  #[special(special_max_up, SKL::Limited)]  pub max_batch_up: u32,
+  #[deftly(limited)] pub max_batch_down:               u32,
+  #[deftly(limited)] pub max_queue_time:               Duration,
+  #[deftly(limited)] pub http_timeout:                 Duration,
+  #[deftly(limited)] pub target_requests_outstanding:  u32,
+  #[deftly(special, skl="SKL::Limited")]  pub max_batch_up: u32,
 
   // Ordinary settings, used by both, not client-specifi:
-  #[global]  pub addrs:                        Vec<IpAddr>,
-  #[global]  pub vnetwork:                     Vec<IpNet>,
-  #[global]  pub vaddr:                        IpAddr,
-  #[global]  pub vrelay:                       IpAddr,
-  #[global]  pub port:                         u16,
-  #[global]  pub mtu:                          u32,
+  #[deftly(global)]  pub addrs:                        Vec<IpAddr>,
+  #[deftly(global)]  pub vnetwork:                     Vec<IpNet>,
+  #[deftly(global)]  pub vaddr:                        IpAddr,
+  #[deftly(global)]  pub vrelay:                       IpAddr,
+  #[deftly(global)]  pub port:                         u16,
+  #[deftly(global)]  pub mtu:                          u32,
 
   // Ordinary settings, used by server only:
-  #[server] #[per_client] pub max_clock_skew:               Duration,
-  #[server] #[global]     pub ifname_server:                String,
+  #[deftly(server, per_client)] pub max_clock_skew:               Duration,
+  #[deftly(server, global)]     pub ifname_server:                String,
 
   // Ordinary settings, used by client only:
-  #[client]  pub http_timeout_grace:           Duration,
-  #[client]  pub max_requests_outstanding:     u32,
-  #[client]  pub http_retry:                   Duration,
-  #[client]  pub success_report_interval:      Duration,
-  #[client]  pub url:                          Url,
-  #[client]  pub vroutes:                      Vec<IpNet>,
-  #[client]  pub ifname_client:                String,
+  #[deftly(client)]  pub http_timeout_grace:           Duration,
+  #[deftly(client)]  pub max_requests_outstanding:     u32,
+  #[deftly(client)]  pub http_retry:                   Duration,
+  #[deftly(client)]  pub success_report_interval:      Duration,
+  #[deftly(client)]  pub url:                          Url,
+  #[deftly(client)]  pub vroutes:                      Vec<IpNet>,
+  #[deftly(client)]  pub ifname_client:                String,
 
   // Computed, rather than looked up.  Client only:
-  #[computed]  pub effective_http_timeout:     Duration,
+  #[deftly(computed)]  pub effective_http_timeout:     Duration,
 }
 
 static DEFAULT_CONFIG: &str = r#"
@@ -113,7 +114,6 @@ impl InspectableConfig for InstanceConfig {
   fn inspect_key(&self, field: &'_ str)
                  -> Option<&dyn InspectableConfigValue> {
     Some(match field {
-      "link" => &self.link,
       "server" => &self.link.server,
       "client" => &self.link.client,
       k => return self.inspect_key_auto(k),
@@ -615,7 +615,7 @@ struct ResolveContext<'c> {
 trait Parseable: Sized {
   fn parse(s: Option<&str>) -> Result<Self, AE>;
 
-  /// Used for lookups with [`ResolveContest::ordinary`] etc.
+  /// Used for lookups with [`ResolveContext::ordinary`] etc.
   ///
   /// Fails, if this setting ought to have been specified.
   /// The caller will add a key name to the error.
@@ -626,9 +626,9 @@ trait Parseable: Sized {
   /// Placeholder (infalliable)
   ///
   /// Used (sometimes) for lookups with
-  /// [`ResolveContest::client`],
-  /// [`server`](`ResolveContest::server`) and
-  /// [`computed`](`ResolveContest::server`).
+  /// [`ResolveContext::client`],
+  /// [`server`](`ResolveContext::server`) and
+  /// [`computed`](`ResolveContext::server`).
   ///
   /// Ie, when the value need not be specified because
   /// it may not be applicable, or could be computed.
@@ -844,7 +844,7 @@ impl<'c> ResolveContext<'c> {
   }
 
   #[throws(AE)]
-  pub fn special_max_up(&self, key: &'static str, skl: SKL) -> u32 {
+  pub fn special_max_batch_up(&self, key: &'static str, skl: SKL) -> u32 {
     assert_eq!(skl, SKL::Limited);
     match self.end {
       LinkEnd::Client => self.ordinary(key, SKL::Limited)?,
