@@ -21,6 +21,9 @@
 
 pub mod prelude;
 
+#[macro_use]
+pub mod config_derive;
+
 pub mod compat;
 pub mod config;
 pub mod ipif;
